@@ -31,6 +31,7 @@
 
 #include <QInputDialog>
 #include <QProcess>
+#include <QThread>
 #include <QString>
 #include <QStringBuilder>
 #include <QMap>
@@ -139,7 +140,7 @@ static const char* pInfo[NUM_LANG_WITH_INFO]={
 
 int numberOfPluralFormsFromHeader(const QString& header)
 {
-    QRegExp rxplural("Plural-Forms:\\s*nplurals=(.);");
+    QRegExp rxplural(QStringLiteral("Plural-Forms:\\s*nplurals=(.);"));
     if (rxplural.indexIn(header) == -1)
         return 0;
     bool ok;
@@ -152,7 +153,7 @@ int numberOfPluralFormsForLangCode(const QString& langCode)
 {
     QString expr=GNUPluralForms(langCode);
 
-    QRegExp rxplural("nplurals=(.);");
+    QRegExp rxplural(QStringLiteral("nplurals=(.);"));
     if (rxplural.indexIn(expr) == -1)
         return 0;
     bool ok;
@@ -175,19 +176,19 @@ QString GNUPluralForms(const QString& lang)
     //BEGIN alternative
     // NOTE does this work under M$ OS?
     qWarning()<<"gonna call msginit";
-    QString def="nplurals=2; plural=n != 1;";
+    QString def=QStringLiteral("nplurals=2; plural=n != 1;");
 
     QStringList arguments;
-    arguments << "-l" << lang
-              << "-i" << "-"
-              << "-o" << "-"
-              << "--no-translator"
-              << "--no-wrap";
+    arguments << QLatin1String("-l") << lang
+              << QLatin1String("-i") << QLatin1String("-")
+              << QLatin1String("-o") << QLatin1String("-")
+              << QLatin1String("--no-translator")
+              << QLatin1String("--no-wrap");
     QProcess msginit;
-    msginit.start("msginit", arguments);
+    msginit.start(QLatin1String("msginit"), arguments);
 
     msginit.waitForStarted(5000);
-    if (KDE_ISUNLIKELY( msginit.state()!=QProcess::Running ))
+    if (Q_UNLIKELY( msginit.state()!=QProcess::Running ))
     {
         //qWarning()<<"msginit error";
         return def;
@@ -214,7 +215,7 @@ QString GNUPluralForms(const QString& lang)
                   );
     msginit.closeWriteChannel();
 
-    if (KDE_ISUNLIKELY( !msginit.waitForFinished(5000) ))
+    if (Q_UNLIKELY( !msginit.waitForFinished(5000) ))
     {
         qWarning()<<"msginit error";
         return def;
@@ -223,7 +224,7 @@ QString GNUPluralForms(const QString& lang)
 
     QByteArray result = msginit.readAll();
     int pos = result.indexOf("Plural-Forms: ");
-    if (KDE_ISUNLIKELY( pos==-1 ))
+    if (Q_UNLIKELY( pos==-1 ))
     {
         //qWarning()<<"msginit error"<<result;
         return def;
@@ -231,7 +232,7 @@ QString GNUPluralForms(const QString& lang)
     pos+=14;
 
     int end = result.indexOf('"',pos);
-    if (KDE_ISUNLIKELY( pos==-1 ))
+    if (Q_UNLIKELY( pos==-1 ))
     {
         //qWarning()<<"msginit error"<<result;
         return def;
@@ -262,12 +263,14 @@ void updateHeader(QString& header,
     QString temp;
     QString authorNameEmail;
 
+    const QString BACKSLASH_N = QStringLiteral("\\n");
+
     // Unwrap header since the following code
     // assumes one header item per headerList element
     it = headerList.begin();
     while ( it != headerList.end() )
     {
-        if (!(*it).endsWith("\\n"))
+        if (!(*it).endsWith(BACKSLASH_N))
         {
             const QString line = *it;
             it = headerList.erase(it);
@@ -291,7 +294,7 @@ void updateHeader(QString& header,
     authorNameEmail=Settings::authorName();
     if (!Settings::authorEmail().isEmpty())
         authorNameEmail+=(QStringLiteral(" <")%Settings::authorEmail()%'>');
-    temp=QStringLiteral("Last-Translator: ")%authorNameEmail%("\\n");
+    temp=QStringLiteral("Last-Translator: ") % authorNameEmail % BACKSLASH_N;
 
     QRegExp lt(QStringLiteral("^ *Last-Translator:.*"));
     for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
@@ -302,24 +305,24 @@ void updateHeader(QString& header,
             found=true;
         }
     }
-    if (KDE_ISUNLIKELY( !found ))
+    if (Q_UNLIKELY( !found ))
         headerList.append(temp);
 
     QString dateTimeString = QDateTime::currentDateTime().toString(QStringLiteral("yyyy-MM-dd hh:mm"));
     QString zoneOffsetString1 = QTimeZone(QTimeZone::systemTimeZoneId()).displayName(QTimeZone::GenericTime, QTimeZone::OffsetName);
     int zpos=qMax(qMax(0, zoneOffsetString1.indexOf('+')), zoneOffsetString1.indexOf('-'));
     QString zoneOffsetString = QString::fromRawData(zoneOffsetString1.unicode()+zpos, zoneOffsetString1.length()-zpos);
-    temp=QStringLiteral("PO-Revision-Date: ")%dateTimeString%zoneOffsetString.remove(':')%QStringLiteral("\\n");
+    temp=QStringLiteral("PO-Revision-Date: ") % dateTimeString % zoneOffsetString.remove(':') % BACKSLASH_N;
     QRegExp poRevDate(QStringLiteral("^ *PO-Revision-Date:.*"));
     for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
     {
         found=it->contains(poRevDate);
         if (found && forSaving) *it = temp;
     }
-    if (KDE_ISUNLIKELY( !found ))
+    if (Q_UNLIKELY( !found ))
         headerList.append(temp);
 
-    temp=QStringLiteral("Project-Id-Version: ")%CatalogProjectId%QStringLiteral("\\n");
+    temp=QStringLiteral("Project-Id-Version: ") % CatalogProjectId % BACKSLASH_N;
     //temp.replace( "@PACKAGE@", packageName());
     QRegExp projectIdVer(QStringLiteral("^ *Project-Id-Version:.*"));
     for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
@@ -328,7 +331,7 @@ void updateHeader(QString& header,
         if (found && it->contains(QLatin1String("PACKAGE VERSION")))
             *it = temp;
     }
-    if (KDE_ISUNLIKELY( !found ))
+    if (Q_UNLIKELY( !found ))
         headerList.append(temp);
 
     
@@ -390,7 +393,7 @@ void updateHeader(QString& header,
         headerList.append(temp);
 
     static QRegExp langCodeRegExp(QStringLiteral("^ *Language: *([^ \\\\]*)"));
-    temp=QStringLiteral("Language: ")%langCode%QStringLiteral("\\n");
+    temp=QStringLiteral("Language: ") % langCode % BACKSLASH_N;
     for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
     {
         found=(langCodeRegExp.indexIn(*it)!=-1);
@@ -398,21 +401,20 @@ void updateHeader(QString& header,
             *it=temp;
         //if (found) qWarning()<<"got explicit lang code:"<<langCodeRegExp.cap(1);
     }
-    if (KDE_ISUNLIKELY( !found ))
+    if (Q_UNLIKELY( !found ))
         headerList.append(temp);
 
-    temp=QStringLiteral("Content-Type: text/plain; charset=")%codec->name()%QStringLiteral("\\n");
+    temp=QStringLiteral("Content-Type: text/plain; charset=") % codec->name() % BACKSLASH_N;
     QRegExp ctRe(QStringLiteral("^ *Content-Type:.*"));
     for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
     {
         found=it->contains(ctRe);
         if (found) *it=temp;
     }
-    if (KDE_ISUNLIKELY( !found ))
+    if (Q_UNLIKELY( !found ))
         headerList.append(temp);
 
 
-    found=false;
     temp=QStringLiteral("Content-Transfer-Encoding: 8bit\\n");
     QRegExp cteRe(QStringLiteral("^ *Content-Transfer-Encoding:.*"));
     for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
@@ -428,7 +430,7 @@ void updateHeader(QString& header,
         found=it->contains(mvRe);
         if (found) *it = temp;
     }
-    if (KDE_ISUNLIKELY( !found ))
+    if (Q_UNLIKELY( !found ))
         headerList.append(temp);
 
 
@@ -456,7 +458,7 @@ void updateHeader(QString& header,
                 {
                     static QRegExp pf(QStringLiteral("^ *Plural-Forms:\\s*nplurals.*\\\\n"));
                     pf.setMinimal(true);
-                    temp=QString(QStringLiteral("Plural-Forms: %1\\n")).arg(t);
+                    temp=QStringLiteral("Plural-Forms: %1\\n").arg(t);
                     it->replace(pf,temp);
                     num=numberOfPluralFormsFromHeader(temp);
                 }
@@ -473,28 +475,27 @@ void updateHeader(QString& header,
     else if ( !generatedFromDocbook)
     {
         //qDebug()<<"generating GNUPluralForms"<<langCode;
-        QString t= GNUPluralForms(langCode);
+        QString t = GNUPluralForms(langCode);
         //qDebug()<<"here it is:";
         if ( !t.isEmpty() ) {
-            const QString pluralFormLine=QString(QStringLiteral("Plural-Forms: %1\\n")).arg(t);
+            const QString pluralFormLine=QStringLiteral("Plural-Forms: %1\\n").arg(t);
             headerList.append(pluralFormLine);
             numberOfPluralForms=numberOfPluralFormsFromHeader(pluralFormLine);
         }
     }
 
-    temp=QStringLiteral("X-Generator: Lokalize %1\\n");
-    temp=temp.arg(LOKALIZE_VERSION);
+    temp=QStringLiteral("X-Generator: Lokalize %1\\n").arg(QStringLiteral(LOKALIZE_VERSION));
     QRegExp xgRe(QStringLiteral("^ *X-Generator:.*"));
     for ( it = headerList.begin(),found=false; it != headerList.end()&& !found; ++it )
     {
         found=it->contains(xgRe);
         if (found) *it = temp;
     }
-    if (KDE_ISUNLIKELY( !found ))
+    if (Q_UNLIKELY( !found ))
         headerList.append(temp);
 
     //m_header.setMsgstr( headerList.join( "\n" ) );
-    header=headerList.join("\n");
+    header=headerList.join(QStringLiteral("\n"));
 //END header itself
 
 //BEGIN comment = description, copyrights
@@ -611,7 +612,7 @@ void updateHeader(QString& header,
         while ( it != commentList.end() )
         {
             bool deleteItem = false;
-            if ( it->indexOf( QStringLiteral("copyright"), 0, Qt::CaseInsensitive ) != -1 )
+            if ( it->indexOf( QLatin1String("copyright"), 0, Qt::CaseInsensitive ) != -1 )
             {
                 // We have a line with a copyright. It should not be moved.
             }
@@ -624,9 +625,9 @@ void updateHeader(QString& header,
                 // Remove the entry
                 deleteItem = true;
             }
-            else if ( it->contains( QStringLiteral("# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.")) )
+            else if ( it->contains( QLatin1String("# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.")) )
                 deleteItem = true;
-            else if ( it->contains( QStringLiteral("# SOME DESCRIPTIVE TITLE")))
+            else if ( it->contains( QLatin1String("# SOME DESCRIPTIVE TITLE")))
                 deleteItem = true;
             else if ( it->contains( regexpAuthorYear ) ) // email address followed by year
             {
@@ -689,13 +690,13 @@ void updateHeader(QString& header,
         foreach (QString author, foundAuthors)
         {
             // ensure dot at the end of copyright
-            if ( !author.endsWith('.') ) author += '.';
+            if ( !author.endsWith(QLatin1Char('.')) ) author += QLatin1Char('.');
             commentList.append(author);
         }
     }
 
     //m_header.setComment( commentList.join( "\n" ) );
-    comment=commentList.join("\n");
+    comment=commentList.join(QStringLiteral("\n"));
 
 //END comment = description, copyrights
 }
@@ -704,39 +705,44 @@ void updateHeader(QString& header,
 
 QString fullUserName();// defined in <platform>helpers.cpp
 
-void askAuthorInfoIfEmpty()
+bool askAuthorInfoIfEmpty()
 {
-    if (Settings::authorName().isEmpty())
+    if(QThread::currentThread() == qApp->thread())
     {
-        bool ok;
-        QString contact = QInputDialog::getText(
-            SettingsController::instance()->mainWindowPtr(),
-            i18nc("@window:title", "Author name missing"), i18n("Your name:"),
-            QLineEdit::Normal, fullUserName(), &ok);
 
-#ifndef NOKDE
-        Settings::self()->authorNameItem()->setValue(ok?contact:fullUserName());
-        Settings::self()->save();
-#else
-        Settings::self()->setAuthorName(ok?contact:fullUserName());
-#endif
-    }
-    if (Settings::authorEmail().isEmpty())
-    {
-        bool ok;
-        QString email = QInputDialog::getText(
-            SettingsController::instance()->mainWindowPtr(),
-            i18nc("@window:title", "Author email missing"), i18n("Your email:"),
-            QLineEdit::Normal, QString(), &ok);
-
-        if (ok)
+        if (Settings::authorName().isEmpty())
         {
+            bool ok;
+            QString contact = QInputDialog::getText(
+                SettingsController::instance()->mainWindowPtr(),
+                i18nc("@window:title", "Author name missing"), i18n("Your name:"),
+                QLineEdit::Normal, fullUserName(), &ok);
+
 #ifndef NOKDE
-            Settings::self()->authorEmailItem()->setValue(email);
+            Settings::self()->authorNameItem()->setValue(ok?contact:fullUserName());
             Settings::self()->save();
 #else
-            Settings::self()->setAuthorEmail(email);
+            Settings::self()->setAuthorName(ok?contact:fullUserName());
 #endif
         }
+        if (Settings::authorEmail().isEmpty())
+        {
+            bool ok;
+            QString email = QInputDialog::getText(
+                SettingsController::instance()->mainWindowPtr(),
+                i18nc("@window:title", "Author email missing"), i18n("Your email:"),
+                QLineEdit::Normal, QString(), &ok);
+
+            if (ok)
+            {
+#ifndef NOKDE
+                Settings::self()->authorEmailItem()->setValue(email);
+                Settings::self()->save();
+#else
+                Settings::self()->setAuthorEmail(email);
+#endif
+            }
+        }
     }
+    return !Settings::authorName().isEmpty() && !Settings::authorEmail().isEmpty();
 }
